@@ -13,7 +13,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                      save_results, save_results_dirname, max_errors,
                      save_generate_data, save_generate_data_dirname,
                      save_seeds, save_seeds_dirname, load_seed, export_funs, packages,
-                     summarise_asis, progress)
+                     summarise_asis, warnings_as_errors, progress)
 {
     # This defines the work-flow for the Monte Carlo simulation given the condition (row in Design)
     #  and number of replications desired
@@ -28,7 +28,8 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                    save_generate_data=save_generate_data,
                    save_generate_data_dirname=save_generate_data_dirname,
                    save_seeds=save_seeds, load_seed=load_seed,
-                   save_seeds_dirname=save_seeds_dirname)
+                   save_seeds_dirname=save_seeds_dirname,
+                   warnings_as_errors=warnings_as_errors)
         } else {
             lapply(1L:replications, mainsim, condition=condition,
                    generate=Functions$generate,
@@ -38,7 +39,8 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                    save_generate_data=save_generate_data,
                    save_generate_data_dirname=save_generate_data_dirname,
                    save_seeds=save_seeds, load_seed=load_seed,
-                   save_seeds_dirname=save_seeds_dirname)
+                   save_seeds_dirname=save_seeds_dirname,
+                   warnings_as_errors=warnings_as_errors)
         }
     } else {
         if(MPI){
@@ -48,7 +50,8 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                      analyse=Functions$analyse, fixed_objects=fixed_objects, load_seed=load_seed,
                      max_errors=max_errors, save_generate_data=save_generate_data,
                      save_generate_data_dirname=save_generate_data_dirname, packages=packages,
-                     save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname)
+                     save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname,
+                     warnings_as_errors=warnings_as_errors)
         } else {
             if(!is.null(seed)) parallel::clusterSetRNGStream(cl=cl, seed[condition$ID])
             results <- if(progress){
@@ -59,6 +62,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                                     max_errors=max_errors, save_generate_data=save_generate_data,
                                     save_generate_data_dirname=save_generate_data_dirname,
                                     save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname,
+                                    warnings_as_errors=warnings_as_errors,
                                   cl=cl)
             } else {
                 parallel::parLapply(cl, 1L:replications, mainsim,
@@ -67,7 +71,8 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                                     fixed_objects=fixed_objects, packages=packages,
                                     max_errors=max_errors, save_generate_data=save_generate_data,
                                     save_generate_data_dirname=save_generate_data_dirname,
-                                    save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname)
+                                    save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname,
+                                    warnings_as_errors=warnings_as_errors)
             }
         }
     }
